@@ -28,7 +28,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 
 #include <stdio.h>
 #include <string.h>
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
@@ -834,7 +836,7 @@ extSubtreeFunc(scx, ha)
 			 * instead of an area search.
 			 */
 			Plane *plane = cumDef->cd_planes[DBPlane(lab->lab_type)];
-			Tile *tile = plane->pl_hint;
+			Tile *tile = PlaneGetHint(plane);
 			GOTOPOINT(tile, &r.r_ll);
 			if (TTMaskHasType(&DBConnectTbl[lab->lab_type], TiGetType(tile)))
 			    continue;
