@@ -25,7 +25,7 @@
 #include "utils/utils.h"
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/net2ir/net2ir.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static const char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/net2ir/net2ir.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif /* lint */
 
 #define	INITHASHSIZE	128
@@ -46,9 +46,7 @@ typedef struct
 } LabInfo;
 
 int
-main(argc, argv)
-    int argc;
-    char *argv[];
+main(int argc, char *argv[])
 {
     char line1[LINESIZE], line2[LINESIZE], layer[LINESIZE], label[LINESIZE];
     HashEntry *he;
