@@ -44,8 +44,9 @@ Tclplot_Init(interp)
 
     /* Sanity checks! */
     if (interp == NULL) return TCL_ERROR;
-    if (Tcl_PkgRequire(interp, "Tclmagic", "7.3", 0) == NULL) return TCL_ERROR;
-    if (Tcl_InitStubs(interp, "8.1", 0) == NULL) return TCL_ERROR;
+    if (Tcl_PkgRequire(interp, "Tclmagic", MAGIC_VERSION, 0) == NULL)
+	return TCL_ERROR;
+    if (Tcl_InitStubs(interp, Tclmagic_InitStubsVersion, 0) == NULL) return TCL_ERROR;
 
     TxPrintf("Auto-loading PLOT module\n");
     TxFlushOut();
@@ -66,7 +67,7 @@ Tclplot_Init(interp)
     invplot = TechSectionGetMask("plot", NULL);
     if (!TechLoad(NULL, invplot)) return TCL_ERROR;
 
-    Tcl_PkgProvide(interp, "Plot", "7.3");
+    Tcl_PkgProvide(interp, "Plot", MAGIC_VERSION);
     return TCL_OK;
 }
 
