@@ -9,7 +9,7 @@ set textdefaults [dict create \
 	offset "0 0" \
 	port "0" \
 ]
-	
+
 proc magic::make_texthelper { mgrpath } {
    global typedflt typesticky typeport
    toplevel ${mgrpath}
@@ -64,7 +64,7 @@ proc magic::make_texthelper { mgrpath } {
 
    menubutton ${mgrpath}.just.btn -text "default" -menu ${mgrpath}.just.btn.menu
    menubutton ${mgrpath}.font.btn -text "default" -menu ${mgrpath}.font.btn.menu
-   
+
    button ${mgrpath}.buttonbar.cancel -text "Cancel" -command "wm withdraw ${mgrpath}"
    button ${mgrpath}.buttonbar.apply -text "Apply"
    button ${mgrpath}.buttonbar.okay -text "Okay"
@@ -139,7 +139,7 @@ proc magic::make_texthelper { mgrpath } {
 
    # Set up tag callbacks
 
-   magic::tag select "[magic::tag select]; magic::update_texthelper"
+   magic::tag add select "magic::update_texthelper"
 }
 
 # For all editable selected labels, fill in entries in the
@@ -157,7 +157,12 @@ proc magic::analyze_labels {} {
    set oval [lindex [setlabel offset] 0]
    set lval [lindex [setlabel layer] 0]
    set kval [lindex [setlabel sticky] 0]
-   set pval [lindex [port index] 0]
+   set isport [lindex [port exists] 0]
+   if {$isport} {
+       set pval [lindex [port index] 0]
+   } else {
+       set pval -1
+   }
 
    # Rescale internal units to microns
    set sval [lindex [setlabel size] 0]
@@ -257,6 +262,18 @@ proc magic::change_label {} {
       setlabel layer $ltype
    }
    setlabel sticky $typesticky
+
+   if {$typeport == 1 && $lport != ""} {
+      if {[port exists] == 0} {
+	 port make $lport
+      } else {
+	 port index $lport
+      }
+   } else {
+      if {[port exists] == 1} {
+         port remove
+      }
+   }
 }
 
 proc magic::make_new_label {} {
@@ -306,6 +323,11 @@ proc magic::make_new_label {} {
    }
    if {$typeport == 1 && $lport != ""} {
       port make $lport
+      # Auto-increment the value to the next available port.
+      set pval [port last]
+      incr pval
+      .texthelper.port.tent delete 0 end
+      .texthelper.port.tent insert 0 $pval
    } else {
       port remove
    }
@@ -339,7 +361,7 @@ proc magic::update_texthelper {} {
    # Reduce list to what's editable
    set slist []
    foreach sitem $splist {
-      set scell [lindex $sitem 2] 
+      set scell [lindex $sitem 2]
       if {$scell == {}} {
          lappend slist $sitem
       }
